from setuptools import setup

setup(name='distributions_gaussian_binomial',
      version='0.3',
      description='Binomial and Gaussian distributions',
      packages=['distributions_gaussian_binomial'],
      zip_safe=False)
